@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (C) 2009-2015 VMware, Inc. All rights reserved.
+ * Copyright (c) 2009-2024 Broadcom. All Rights Reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -19,7 +20,6 @@
 #ifndef _USERLOCK_H_
 #define _USERLOCK_H_
 
-
 #define INCLUDE_ALLOW_USERLEVEL
 #define INCLUDE_ALLOW_VMCORE
 #include "includeCheck.h"
@@ -32,14 +32,19 @@
 #include "mutexRank.h"
 #include "vthreadBase.h"
 
-typedef struct MXUserExclLock   MXUserExclLock;
-typedef struct MXUserRecLock    MXUserRecLock;
-typedef struct MXUserRWLock     MXUserRWLock;
-typedef struct MXUserRankLock   MXUserRankLock;
-typedef struct MXUserCondVar    MXUserCondVar;
-typedef struct MXUserSemaphore  MXUserSemaphore;
-typedef struct MXUserEvent      MXUserEvent;
-typedef struct MXUserBarrier    MXUserBarrier;
+#if defined(__cplusplus)
+extern "C" {
+#endif
+
+typedef struct MXUserExclLock      MXUserExclLock;
+typedef struct MXUserRecLock       MXUserRecLock;
+typedef struct MXUserRWLock        MXUserRWLock;
+typedef struct MXUserRankLock      MXUserRankLock;
+typedef struct MXUserCondVar       MXUserCondVar;
+typedef struct MXUserSemaphore     MXUserSemaphore;
+typedef struct MXUserBinSemaphore  MXUserBinSemaphore;
+typedef struct MXUserEvent         MXUserEvent;
+typedef struct MXUserBarrier       MXUserBarrier;
 
 /*
  * Exclusive ownership lock
@@ -54,9 +59,29 @@ void MXUser_ReleaseExclLock(MXUserExclLock *lock);
 void MXUser_DestroyExclLock(MXUserExclLock *lock);
 Bool MXUser_IsCurThreadHoldingExclLock(MXUserExclLock *lock);
 
-MXUserExclLock *MXUser_CreateSingletonExclLock(Atomic_Ptr *lockStorage,
-                                               const char *name,
-                                               MX_Rank rank);
+/* Use only when necessary */
+MXUserExclLock *MXUser_CreateSingletonExclLockInt(Atomic_Ptr *lockStorage,
+                                                  const char *name,
+                                                  MX_Rank rank);
+
+/* This is the public interface */
+static INLINE MXUserExclLock *
+MXUser_CreateSingletonExclLock(Atomic_Ptr *lockStorage,
+                               const char *name,
+                               MX_Rank rank)
+{
+   MXUserExclLock *lock;
+
+   ASSERT(lockStorage);
+
+   lock = (MXUserExclLock *) Atomic_ReadPtr(lockStorage);
+
+   if (UNLIKELY(lock == NULL)) {
+      lock = MXUser_CreateSingletonExclLockInt(lockStorage, name, rank);
+   }
+
+   return lock;
+}
 
 MXUserCondVar *MXUser_CreateCondVarExclLock(MXUserExclLock *lock);
 
@@ -65,7 +90,7 @@ void MXUser_WaitCondVarExclLock(MXUserExclLock *lock,
 
 void MXUser_TimedWaitCondVarExclLock(MXUserExclLock *lock,
                                      MXUserCondVar *condVar,
-                                     uint32 msecWait);
+                                     uint32 waitTimeMS);
 
 Bool MXUser_EnableStatsExclLock(MXUserExclLock *lock,
                                 Bool trackAcquisitionTime,
@@ -95,9 +120,29 @@ void MXUser_ReleaseRecLock(MXUserRecLock *lock);
 void MXUser_DestroyRecLock(MXUserRecLock *lock);
 Bool MXUser_IsCurThreadHoldingRecLock(MXUserRecLock *lock);
 
-MXUserRecLock *MXUser_CreateSingletonRecLock(Atomic_Ptr *lockStorage,
-                                             const char *name,
-                                             MX_Rank rank);
+/* Use only when necessary */
+MXUserRecLock *MXUser_CreateSingletonRecLockInt(Atomic_Ptr *lockStorage,
+                                                const char *name,
+                                                MX_Rank rank);
+
+/* This is the public interface */
+static INLINE MXUserRecLock *
+MXUser_CreateSingletonRecLock(Atomic_Ptr *lockStorage,
+                              const char *name,
+                              MX_Rank rank)
+{
+   MXUserRecLock *lock;
+
+   ASSERT(lockStorage);
+
+   lock = (MXUserRecLock *) Atomic_ReadPtr(lockStorage);
+
+   if (UNLIKELY(lock == NULL)) {
+      lock = MXUser_CreateSingletonRecLockInt(lockStorage, name, rank);
+   }
+
+   return lock;
+}
 
 void MXUser_DumpRecLock(MXUserRecLock *lock);
 
@@ -108,7 +153,7 @@ void MXUser_WaitCondVarRecLock(MXUserRecLock *lock,
 
 void MXUser_TimedWaitCondVarRecLock(MXUserRecLock *lock,
                                     MXUserCondVar *condVar,
-                                    uint32 msecWait);
+                                    uint32 waitTimeMS);
 
 void MXUser_IncRefRecLock(MXUserRecLock *lock);
 
@@ -149,9 +194,29 @@ void MXUser_DestroyRWLock(MXUserRWLock *lock);
 Bool MXUser_IsCurThreadHoldingRWLock(MXUserRWLock *lock,
                                      uint32 queryType);
 
-MXUserRWLock *MXUser_CreateSingletonRWLock(Atomic_Ptr *lockStorage,
-                                           const char *name,
-                                           MX_Rank rank);
+/* Use only when necessary */
+MXUserRWLock *MXUser_CreateSingletonRWLockInt(Atomic_Ptr *lockStorage,
+                                              const char *name,
+                                              MX_Rank rank);
+
+/* This is the public interface */
+static INLINE MXUserRWLock *
+MXUser_CreateSingletonRWLock(Atomic_Ptr *lockStorage,
+                             const char *name,
+                             MX_Rank rank)
+{
+   MXUserRWLock *lock;
+
+   ASSERT(lockStorage);
+
+   lock = (MXUserRWLock *) Atomic_ReadPtr(lockStorage);
+
+   if (UNLIKELY(lock == NULL)) {
+      lock = MXUser_CreateSingletonRWLockInt(lockStorage, name, rank);
+   }
+
+   return lock;
+}
 
 /*
  * Stateful auto-reset event
@@ -163,7 +228,7 @@ MXUserEvent *MXUser_CreateEvent(const char *name,
 void MXUser_SignalEvent(MXUserEvent *event);
 void MXUser_WaitEvent(MXUserEvent *event);
 Bool MXUser_TryWaitEvent(MXUserEvent *event);
-MXSemaHandle MXUser_GetHandleForEvent(MXUserEvent *event);
+PollDevHandle MXUser_GetHandleForEvent(MXUserEvent *event);
 void MXUser_DestroyEvent(MXUserEvent *event);
 
 MXUserEvent *MXUser_CreateSingletonEvent(Atomic_Ptr *eventStorage,
@@ -199,12 +264,31 @@ void MXUser_DownSemaphore(MXUserSemaphore *sema);
 Bool MXUser_TryDownSemaphore(MXUserSemaphore *sema);
 
 Bool MXUser_TimedDownSemaphore(MXUserSemaphore *sema,
-                               uint32 msecWait);
+                               uint32 waitTimeMS);
+Bool MXUser_TimedDownSemaphoreNS(MXUserSemaphore *sema,
+                                 uint64 waitTimeNS);
 
 MXUserSemaphore *MXUser_CreateSingletonSemaphore(Atomic_Ptr *semaStorage,
                                                  const char *name,
                                                  MX_Rank rank);
 
+/*
+ * Binary semaphore
+ */
+
+MXUserBinSemaphore *MXUser_CreateBinSemaphore(const char *name,
+                                              MX_Rank rank);
+
+void MXUser_DestroyBinSemaphore(MXUserBinSemaphore *binSema);
+void MXUser_UpBinSemaphore(MXUserBinSemaphore *binSema);
+void MXUser_DownBinSemaphore(MXUserBinSemaphore *binSema);
+Bool MXUser_TryDownBinSemaphore(MXUserBinSemaphore *binSema);
+
+Bool MXUser_TimedDownBinSemaphore(MXUserBinSemaphore *binSema,
+                                  uint32 waitTimeMS);
+Bool MXUser_TimedDownBinSemaphoreNS(MXUserBinSemaphore *binSema,
+                                    uint64 waitTimeNS);
+
 /*
  * Rank lock
  *
@@ -268,4 +352,9 @@ MXUserRecLock       *MXUser_BindMXMutexRec(struct MX_MutexRec *mutex,
 
 struct MX_MutexRec  *MXUser_GetRecLockVmm(MXUserRecLock *lock);
 MX_Rank              MXUser_GetRecLockRank(MXUserRecLock *lock);
+
+#if defined(__cplusplus)
+}  // extern "C"
+#endif
+
 #endif  // _USERLOCK_H_
