@@ -1,5 +1,5 @@
 /*********************************************************
- * Copyright (C) 2010-2015 VMware, Inc. All rights reserved.
+ * Copyright (c) 2010-2018,2022 VMware, Inc. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -82,25 +82,25 @@ InitGroupLeader(Window *groupLeader,
 
    gdkDisplay = gdk_display_get_default();
    gdkLeader = gdk_display_get_default_group(gdkDisplay);
-   myGroupLeader = GDK_WINDOW_XWINDOW(gdkLeader);
+   myGroupLeader = GDK_WINDOW_XID(gdkLeader);
    myRootWindow = GDK_ROOT_WINDOW();
 
    ASSERT(myGroupLeader);
    ASSERT(myRootWindow);
 
    /* XXX: With g_set_prgname() being called, this can probably go away. */
-   XStoreName(GDK_DISPLAY(), myGroupLeader, VMUSER_TITLE);
+   XStoreName(gdk_x11_get_default_xdisplay(), myGroupLeader, VMUSER_TITLE);
 
    /*
-    * Sanity check:  Set the override redirect property on our group leader
+    * Confidence check:  Set the override redirect property on our group leader
     * window (not default), then re-parent it to the root window (default).
     * This makes sure that (a) a window manager can't re-parent our window,
     * and (b) that we remain a top-level window.
     */
-   XChangeWindowAttributes(GDK_DISPLAY(), myGroupLeader, CWOverrideRedirect,
+   XChangeWindowAttributes(gdk_x11_get_default_xdisplay(), myGroupLeader, CWOverrideRedirect,
                            &attr);
-   XReparentWindow(GDK_DISPLAY(), myGroupLeader, myRootWindow, 10, 10);
-   XSync(GDK_DISPLAY(), FALSE);
+   XReparentWindow(gdk_x11_get_default_xdisplay(), myGroupLeader, myRootWindow, 10, 10);
+   XSync(gdk_x11_get_default_xdisplay(), FALSE);
 
    *groupLeader = myGroupLeader;
    *rootWindow = myRootWindow;
@@ -161,6 +161,43 @@ QueryX11Lock(Display *dpy,
 }
 
 
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * FetchNameErrorHandler --
+ *
+ *      According to XFetchName document, XFetchName may generate a BadWindow
+ *      error. In this case, the pointer we pass to XFetchName doesn't name a
+ *      defined window. X is asynchronous, there isn't a gurantee that the
+ *      window is still alive between the time the window is obtained and
+ *      the time a event is sent to the window. So, for this scenario, since
+ *      the window doesn't exist, we can ignore checking its name. This can
+ *      avoid this plugin from crashing. Refer to PR 1871141 for details.
+ *
+ * Results:
+ *      Logs error.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+static int
+FetchNameErrorHandler(Display *display,
+                      XErrorEvent *error)
+{
+   /* 256 is enough for the error description. */
+   char msg[256];
+   XGetErrorText(display, error->error_code, msg, sizeof(msg));
+
+   g_warning("X Error %d (%s): request %d.%d\n",
+             error->error_code, msg, error->request_code, error->minor_code);
+
+   return 0;
+}
+
+
 /*
  ******************************************************************************
  * AcquireDisplayLock --                                                */ /**
@@ -216,7 +253,7 @@ AcquireDisplayLock(void)
    Bool alreadyLocked = FALSE;  // Set to TRUE if we discover lock is held.
    Bool retval = FALSE;
 
-   defaultDisplay = GDK_DISPLAY();
+   defaultDisplay = gdk_x11_get_default_xdisplay();
 
    /*
     * Reset some of our main window's settings & fetch Xlib handles for
@@ -281,15 +318,24 @@ AcquireDisplayLock(void)
     */
    for (index = 0; (index < nchildren) && !alreadyLocked; index++) {
       char *name = NULL;
+      /* Use customized error handler to suppress BadWindow error. */
+      int (*oldXErrorHandler)(Display*, XErrorEvent*) =
+         XSetErrorHandler(FetchNameErrorHandler);
 
       /* Skip unless window is named vmware-user. */
       if ((XFetchName(defaultDisplay, children[index], &name) == 0) ||
           (name == NULL) ||
           strcmp(name, VMUSER_TITLE)) {
          XFree(name);
+
+         /* Restore default error handler. */
+         XSetErrorHandler(oldXErrorHandler);
          continue;
       }
 
+      /* Restore default error handler. */
+      XSetErrorHandler(oldXErrorHandler);
+
       /*
        * Query the window for the "vmware-user-lock" property.
        */
@@ -364,6 +410,16 @@ X11Lock_Init(ToolsAppCtx *ctx,
    g_set_prgname(VMUSER_TITLE);
    argv[0] = VMUSER_TITLE;
 
+#if GTK_MAJOR_VERSION > 3 || (GTK_MAJOR_VERSION == 3 && GTK_MINOR_VERSION >= 10)
+   /*
+    * On recent distros, Wayland is the default display server. If the obtained
+    * display or window is a wayland one, applying X11 specific functions on them
+    * will result in crashes. Before migrating the X11 specific code to Wayland,
+    * force using X11 as the backend of Gtk+3. gdk_set_allowed_backends() is
+    * introduced since Gtk+3.10 and Wayland is supported from Gtk+3.10.
+    */
+   gdk_set_allowed_backends("x11");
+#endif
    /* XXX: is calling gtk_init() multiple times safe? */
    gtk_init(&argc, (char ***) &argv);
 
