@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (C) 2008-2015 VMware, Inc. All rights reserved.
+ * Copyright (c) 2008-2024 Broadcom. All Rights Reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -34,7 +35,6 @@
 
 #include "resolutionInt.h"
 
-#include "xdrutil.h"
 #include "vmware/guestrpc/tclodefs.h"
 #include "vmware/tools/plugin.h"
 #include "vmware/tools/utils.h"
@@ -76,8 +76,7 @@ ResolutionInfoType resolutionInfo;
  *
  * Initialize the guest resolution library.
  *
- * @param[in] handle  Back-end specific handle, if needed.  E.g., in the X11
-                      case, this refers to the X11 display handle.
+ * @param[in] handle  Back-end specific handle, if needed.
  * @return TRUE on success, FALSE on failure
  */
 
@@ -512,6 +511,12 @@ ResolutionSetCapabilities(gpointer src,
 
    ASSERT(capabilityCount <= RESOLUTION_SET_CAPABILITIES_MAX);
 
+   /*
+    * VMTools_WrapArray copies the first capabilityCount elements from
+    * capabilityArray to the returned GArray. The uninitialized elements are not
+    * used.
+    */
+   /* coverity[uninit_use_in_call] */
    return VMTools_WrapArray(capabilityArray,
                             sizeof *capabilityArray,
                             capabilityCount);
@@ -584,9 +589,10 @@ ToolsOnLoad(ToolsAppCtx *ctx)
    /*
     * XXX move to some shared lib or plugin
     */
-   handle = ResolutionToolkitInit();
+   handle = ResolutionToolkitInit(ctx);
 
-   ResolutionInit(handle);
+   if (!ResolutionInit(handle))
+      return NULL;
 
    regs[0].data = VMTools_WrapArray(rpcs, sizeof *rpcs, ARRAYSIZE(rpcs));
    regData.regs = VMTools_WrapArray(regs, sizeof *regs, ARRAYSIZE(regs));
