@@ -1,5 +1,6 @@
 /*********************************************************
- * Copyright (C) 2008-2017 VMware, Inc. All rights reserved.
+ * Copyright (c) 2008-2021,2023-2024 Broadcom. All Rights Reserved.
+ * The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -44,6 +45,7 @@
 #include "vmware/tools/guestrpc.h"
 #include "vm_version.h"
 
+
 /**
  * Runs the given Tools RPC command, printing the result to the terminal and
  * exiting the application afterwards.
@@ -67,9 +69,7 @@ ToolsCoreRunCommand(const gchar *option,
 #endif
    if (VmCheck_IsVirtualWorld()) {
       char *result = NULL;
-      Bool status = FALSE;
-
-      status = RpcChannel_SendOne(&result, NULL, "%s", value);
+      Bool status = RpcChannel_SendOne(&result, NULL, "%s", value);
 
       if (!status) {
          g_printerr("%s\n", result ? result : "NULL");
@@ -86,6 +86,60 @@ ToolsCoreRunCommand(const gchar *option,
 }
 
 
+/**
+ * Reads the contents of a file and runs it as a Tools RPC command,
+ * printing the result to the terminal and
+ * exiting the application afterwards.
+ *
+ * @param[in]  option      Unused.
+ * @param[in]  fileName    Name of the file containing an RPC command.
+ * @param[in]  data        Unused.
+ * @param[out] error       Unused.
+ *
+ * @return This function doesn't return.
+ */
+
+static gboolean
+ToolsCoreRunCommandFromFile(const gchar *option,
+                            const gchar *fileName,
+                            gpointer data,
+                            GError **error)
+{
+#if defined(_WIN32)
+   VMTools_AttachConsole();
+#endif
+   if (VmCheck_IsVirtualWorld()) {
+      char *result = NULL;
+      Bool status;
+      gchar *fileContents = NULL;
+
+      if (!g_file_get_contents(fileName, &fileContents, NULL, NULL)) {
+         g_printerr(SU_(cmdline.cmdfile.read,
+                        "Unable to read command from file %s.\n"),
+                        fileName);
+         exit(1);
+      }
+
+      g_strchomp(fileContents);
+
+      status = RpcChannel_SendOne(&result, NULL, "%s", fileContents);
+      if (!status) {
+         g_printerr("%s\n", (NULL != result) ? result : "NULL");
+      } else {
+         g_print("%s\n", result);
+      }
+
+      g_free(fileContents);
+      vm_free(result);
+      exit(status ? 0 : 1);
+   }
+   g_printerr("%s\n",
+              SU_(cmdline.cmdfile.rpcerror,
+                  "Unable to send command from file to VMware hypervisor."));
+   exit(1);
+}
+
+
 #if defined(G_PLATFORM_WIN32)
 
 /**
@@ -221,7 +275,7 @@ ToolsCore_ParseCommandLine(ToolsServiceState *state,
    gboolean version = FALSE;
 #if defined(G_PLATFORM_WIN32)
    gboolean dumpState = FALSE;
-   gboolean kill = FALSE;
+   gboolean forceQuit = FALSE;
 #endif
    gboolean unused;
    GOptionEntry clOptions[] = {
@@ -237,12 +291,15 @@ ToolsCore_ParseCommandLine(ToolsServiceState *state,
       { "cmd", '\0', 0, G_OPTION_ARG_CALLBACK, ToolsCoreRunCommand,
          SU_(cmdline.rpc, "Sends an RPC command to the host and exits."),
          SU_(cmdline.rpc.command, "command") },
+      { "cmdfile", '\0', 0, G_OPTION_ARG_CALLBACK, ToolsCoreRunCommandFromFile,
+         SU_(cmdline.cmdfile, "Sends an RPC command from a file to the host and exits."),
+         SU_(cmdline.cmdfile.command, "command file") },
 #if defined(G_PLATFORM_WIN32)
       { "dump-state", 's', 0, G_OPTION_ARG_NONE, &dumpState,
          SU_(cmdline.state, "Dumps the internal state of a running service instance to the logs."),
          NULL },
-      { "kill", 'k', 0, G_OPTION_ARG_NONE, &kill,
-         SU_(cmdline.kill, "Stops a running instance of a tools service."),
+      { "kill", 'k', 0, G_OPTION_ARG_NONE, &forceQuit,
+         SU_(cmdline.forceQuit, "Stops a running instance of a tools service."),
          NULL },
       { "install", 'i', G_OPTION_FLAG_NO_ARG, G_OPTION_ARG_CALLBACK, ToolsCoreIgnoreArg,
          SU_(cmdline.install, "Installs the service with the Service Control Manager."),
@@ -260,6 +317,9 @@ ToolsCore_ParseCommandLine(ToolsServiceState *state,
       { "blockFd", '\0', 0, G_OPTION_ARG_INT, &state->ctx.blockFD,
          SU_(cmdline.blockfd, "File descriptor for the VMware blocking fs."),
          SU_(cmdline.blockfd.fd, "fd") },
+      { "uinputFd", '\0', 0, G_OPTION_ARG_INT, &state->ctx.uinputFD,
+         SU_(cmdline.uinputfd, "File descriptor for the uinput device."),
+         SU_(cmdline.uinputfd.fd, "fd") },
 #endif
       { "config", 'c', 0, G_OPTION_ARG_FILENAME, &state->configFile,
          SU_(cmdline.config, "Uses the config file at the given path."),
@@ -280,6 +340,7 @@ ToolsCore_ParseCommandLine(ToolsServiceState *state,
 
 #if !defined(G_PLATFORM_WIN32)
    state->ctx.blockFD = -1;
+   state->ctx.uinputFD = -1;
 #endif
 
    /*
@@ -300,9 +361,7 @@ ToolsCore_ParseCommandLine(ToolsServiceState *state,
    }
 
    context = g_option_context_new(NULL);
-#if GLIB_CHECK_VERSION(2, 12, 0)
    g_option_context_set_summary(context, N_("Runs the VMware Tools daemon."));
-#endif
    g_option_context_add_main_entries(context, clOptions, NULL);
    g_option_group_set_error_hook(g_option_context_get_main_group(context),
                                  ToolsCoreCmdLineError);
@@ -337,19 +396,24 @@ ToolsCore_ParseCommandLine(ToolsServiceState *state,
    g_info("CmdLine: \"%s\"\n", cmdStr);
 
 #if defined(G_PLATFORM_WIN32)
-   if (kill) {
+   if (forceQuit) {
       exit(ToolsCoreSignalEvent(state->name, QUIT_EVENT_NAME_FMT) ? 0 : 1);
    }
    if (dumpState) {
       exit(ToolsCoreSignalEvent(state->name, DUMP_STATE_EVENT_NAME_FMT) ? 0 : 1);
    }
 #else
-   /* If not running the "vmusr" service, ignore the blockFd parameter. */
+   /* If not running the "vmusr" service, ignore the blockFd and uinputFd parameter. */
    if (!TOOLS_IS_USER_SERVICE(state)) {
       if (state->ctx.blockFD >= 0) {
          close(state->ctx.blockFD);
       }
       state->ctx.blockFD = -1;
+
+      if (state->ctx.uinputFD >= 0) {
+         close(state->ctx.uinputFD);
+      }
+      state->ctx.uinputFD = -1;
    }
 #endif
 
